@@ -1,27 +1,15 @@
-#include "kgrdebug.h"
+/*
+    SPDX-FileCopyrightText: 2009 Ian Wadham <iandw.au@gmail.com>
 
-/****************************************************************************
- *    Copyright 2009  Ian Wadham <iandw.au@gmail.com>                       *
- *                                                                          *
- *    This program is free software; you can redistribute it and/or         *
- *    modify it under the terms of the GNU General Public License as        *
- *    published by the Free Software Foundation; either version 2 of        *
- *    the License, or (at your option) any later version.                   *
- *                                                                          *
- *    This program is distributed in the hope that it will be useful,       *
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *    GNU General Public License for more details.                          *
- *                                                                          *
- *    You should have received a copy of the GNU General Public License     *
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ****************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgrrunner.h"
 #include "kgrlevelgrid.h"
 #include "kgrrulebook.h"
 #include "kgrlevelplayer.h"
 #include "kgoldrunner_debug.h"
+#include "kgrdebug.h"
 
 KGrRunner::KGrRunner (KGrLevelPlayer * pLevelPlayer, KGrLevelGrid * pGrid,
                       int i, int j, const int pSpriteId,
@@ -653,4 +641,4 @@ void KGrEnemy::showState()
                  gridX, gridY, currAnimation, interval, prevInCell);
 }
 
-
+#include "moc_kgrrunner.cpp"
